
# Slot: comments


notes and comments about an element intended for external consumption

URI: [linkml:comments](https://w3id.org/linkml/comments)


## Domain and Range

[Element](Element.md) &#8594;  <sub>0..\*</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * class_definition
 * common_metadata
 * definition
 * [Element](Element.md)
 * enum_definition
 * permissible_value
 * schema_definition
 * slot_definition
 * subset_definition
 * type_definition

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:note |
| **In Subsets:** | | owl |

